@@ -177,7 +177,7 @@ private Q_SLOTS:
         scope.qresync = true;
         KIMAP::ImapSet vanished;
         vanished.add(KIMAP::ImapInterval{300, 310});
-        vanished.add(QVector<qint64>{405, 411});
+        vanished.add(QList<qint64>{405, 411});
         QTest::newRow("qresync") << true << KIMAP::ImapSet(300, 500) << 3 << scenario << scope << vanished;
     }
 
